@@ -1,4 +1,4 @@
-# @(#)$Id: CPANTesting.pm 195 2012-09-05 14:09:51Z pjf $
+# @(#)$Id: CPANTesting.pm 197 2012-09-06 14:03:51Z pjf $
 
 package CPANTesting;
 
@@ -16,7 +16,9 @@ sub test_exceptions {
 
    $p->{stop_tests} and return 'CPAN Testing stopped in Build.PL';
 
-   $osname eq q(mirbsd)      and return 'Mirbsd OS unsupported';
+   $osname eq q(cygwin)      and return 'Cygwin  OS unsupported';
+   $osname eq q(mirbsd)      and return 'Mirbsd  OS unsupported';
+   $osname eq q(mswin32)     and return 'MSWin32 OS unsupported';
    $uname  =~ m{ slack64 }mx and return 'Stopped Bingos slack64';
    return 0;
 }
